@@ -13,7 +13,7 @@ Usage::
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING, overload
+from typing import Any, Dict, List, TYPE_CHECKING, Type, overload
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_codebuild.paginator import (
     ListBuildsForProjectPaginator,
@@ -78,12 +78,12 @@ __all__ = ("CodeBuildClient",)
 
 
 class Exceptions:
-    AccountLimitExceededException: Boto3ClientError
-    ClientError: Boto3ClientError
-    InvalidInputException: Boto3ClientError
-    OAuthProviderException: Boto3ClientError
-    ResourceAlreadyExistsException: Boto3ClientError
-    ResourceNotFoundException: Boto3ClientError
+    AccountLimitExceededException: Type[Boto3ClientError]
+    ClientError: Type[Boto3ClientError]
+    InvalidInputException: Type[Boto3ClientError]
+    OAuthProviderException: Type[Boto3ClientError]
+    ResourceAlreadyExistsException: Type[Boto3ClientError]
+    ResourceNotFoundException: Type[Boto3ClientError]
 
 
 class CodeBuildClient:
